@@ -1,25 +1,25 @@
-from django.conf.urls import url
+from django.urls import re_path
 from pretalx.event.models.event import SLUG_CHARS
 
 from . import views
 
 urlpatterns = [
-    url(
+    re_path(
         fr"^orga/event/(?P<event>[{SLUG_CHARS}]+)/settings/p/public_voting/$",
-        views.PublicVotingSettings.as_view(),
+        views.PublicVotingSettingsView.as_view(),
         name="settings",
     ),
-    url(
+    re_path(
         f"^(?P<event>[{SLUG_CHARS}]+)/p/voting/signup/$",
         views.SignupView.as_view(),
         name="signup",
     ),
-    url(
+    re_path(
         f"^(?P<event>[{SLUG_CHARS}]+)/p/voting/thanks/$",
         views.ThanksView.as_view(),
         name="thanks",
     ),
-    url(
+    re_path(
         f"^(?P<event>[{SLUG_CHARS}]+)/p/voting/talks/(?P<signed_user>[^/]+)/$",
         views.SubmissionListView.as_view(),
         name="talks",
